# -*- coding:utf-8 -*-
import hashlib
import hmac
import base64
import json
import time

import requests
from requests_toolbelt.multipart.encoder import MultipartEncoder


class AIPPT():

    def __init__(self, APPId, APISecret, Text, templateId):
        self.APPid = APPId
        self.APISecret = APISecret
        self.text = Text
        self.header = {}
        self.templateId = templateId

    # 获取签名
    def get_signature(self, ts):
        try:
            # 对app_id和时间戳进行MD5加密
            auth = self.md5(self.APPid + str(ts))
            # 使用HMAC-SHA1算法对加密后的字符串进行加密
            return self.hmac_sha1_encrypt(auth, self.APISecret)
        except Exception as e:
            print(e)
            return None

    def hmac_sha1_encrypt(self, encrypt_text, encrypt_key):
        # 使用HMAC-SHA1算法对文本进行加密，并将结果转换为Base64编码
        return base64.b64encode(
            hmac.new(encrypt_key.encode('utf-8'), encrypt_text.encode('utf-8'), hashlib.sha1).digest()).decode('utf-8')

    def md5(self, text):
        # 对文本进行MD5加密，并返回加密后的十六进制字符串
        return hashlib.md5(text.encode('utf-8')).hexdigest()

    # 创建PPT生成任务
    def create_task(self):
        url = 'https://zwapi.xfyun.cn/api/ppt/v2/create'
        timestamp = int(time.time())
        signature = self.get_signature(timestamp)
        # body= self.getbody(self.text)

        formData = MultipartEncoder(
            fields={
                # "file": (path, open(path, 'rb'), 'text/plain'),  # 如果需要上传文件，可以将文件路径通过path 传入
                # "fileUrl":"",   #文件地址（file、fileUrl、query必填其一）
                # "fileName":"",   # 文件名(带文件名后缀；如果传file或者fileUrl，fileName必填)
                "query": self.text,
                "templateId": "20240718489569D",  # 模板的ID,从PPT主题列表查询中获取
                "author": "XXXX",  # PPT作者名：用户自行选择是否设置作者名
                "isCardNote": str(True),  # 是否生成PPT演讲备注, True or False
                "search": str(False),  # 是否联网搜索,True or False
                "isFigure": str(True),  # 是否自动配图, True or False
                "aiImage": "normal"
                # ai配图类型： normal、advanced （isFigure为true的话生效）； normal-普通配图，20%正文配图；advanced-高级配图，50%正文配图
            }
        )

        print(formData)

        headers = {
            "appId": self.APPid,
            "timestamp": str(timestamp),
            "signature": signature,
            "Content-Type": formData.content_type
        }
        self.header = headers
        print(headers)
        response = requests.request(method="POST", url=url, data=formData, headers=headers).text
        print("生成PPT返回结果：", response)
        resp = json.loads(response)
        if (0 == resp['code']):
            return resp['data']['sid']
        else:
            print('创建PPT任务失败')
            return None

    # 构建请求body体
    def getbody(self, text):
        body = {
            "query": text,
            "templateId": self.templateId  # 模板ID举例，具体使用 /template/list 查询
        }
        return body

    # 轮询任务进度，返回完整响应信息
    def get_process(self, sid):
        # print("sid:" + sid)
        if (None != sid):
            response = requests.request("GET", url=f"https://zwapi.xfyun.cn/api/ppt/v2/progress?sid={sid}",
                                        headers=self.header).text
            print(response)
            return response
        else:
            return None

    # 获取PPT，以下载连接形式返回
    def get_result(self, task_id):

        # 创建PPT生成任务
        # task_id = self.create_task()
        # PPTurl = ''
        # 轮询任务进度
        while (True):
            response = self.get_process(task_id)
            resp = json.loads(response)
            pptStatus = resp['data']['pptStatus']
            aiImageStatus = resp['data']['aiImageStatus']
            cardNoteStatus = resp['data']['cardNoteStatus']

            if ('done' == pptStatus and 'done' == aiImageStatus and 'done' == cardNoteStatus):
                PPTurl = resp['data']['pptUrl']
                break
            else:
                time.sleep(3)
        return PPTurl

    def getHeaders(self):
        timestamp = int(time.time())
        signature = self.get_signature(timestamp)
        # body = self.getbody(self.text)

        headers = {
            "appId": self.APPid,
            "timestamp": str(timestamp),
            "signature": signature,
            "Content-Type": "application/json; charset=utf-8"
        }
        return headers

    def getTheme(self):
        url = "https://zwapi.xfyun.cn/api/ppt/v2/template/list"
        self.header = self.getHeaders()
        body = {
            "payType": "not_free",
            # "style": "简约",    # 支持按照类型查询PPT 模板
            # "color": "红色",   #  支持按照颜色查询PPT 模板
            # "industry": "教育培训",    # 支持按照颜色查询PPT 模板
            "pageNum": 2,
            "pageSize": 10
        }

        response = requests.request("GET", url=url, headers=self.header).text
        print(response)
        return response

    def createOutline(self):
        # if('' ==fileUrl and '' == filePath):
        url = "https://zwapi.xfyun.cn/api/ppt/v2/createOutline"
        body = {
            "query": self.text,
            "language": "cn",
            "search": str(False),  # 是否联网搜索,True or False
        }

        response = requests.post(url=url, json=body, headers=self.getHeaders()).text
        print("生成大纲完成：\n", response)

        return response

    def createOutlineByDoc(self, fileName, fileUrl=None, filePath=None):
        # if('' ==fileUrl and '' == filePath):
        url = "https://zwapi.xfyun.cn/api/ppt/v2/createOutlineByDoc"
        formData = MultipartEncoder(
            fields={
                "file": (filePath, open(filePath, 'rb'), 'text/plain'),  # 如果需要上传文件，可以将文件路径通过path 传入
                "fileUrl": fileUrl,  # 文件地址（file、fileUrl必填其一）
                "fileName": fileName,  # 文件名(带文件名后缀；如果传file或者fileUrl，fileName必填)
                "query": self.text,
                "language": "cn",
                "search": str(False),  # 是否联网搜索,True or False
            }
        )
        timestamp = int(time.time())
        signature = self.get_signature(timestamp)
        headers = {
            "appId": self.APPid,
            "timestamp": str(timestamp),
            "signature": signature,
            "Content-Type": formData.content_type
        }
        self.header = headers
        response = requests.post(url=url, data=formData, headers=headers).text
        print("生成大纲完成：\n", response)

        return response

    def createPptByOutline(self, outline):
        url = "https://zwapi.xfyun.cn/api/ppt/v2/createPptByOutline"
        body = {
            "query": self.text,
            "outline": outline,
            "templateId": self.templateId,  # 模板的ID,从PPT主题列表查询中获取
            "author": "XXXX",  # PPT作者名：用户自行选择是否设置作者名
            "isCardNote": True,  # 是否生成PPT演讲备注, True or False
            "search": False,  # 是否联网搜索,True or False
            "isFigure": True,  # 是否自动配图, True or False
            "aiImage": "normal",
            # ai配图类型： normal、advanced （isFigure为true的话生效）； normal-普通配图，20%正文配图；advanced-高级配图，50%正文配图

        }
        print(body)

        response = requests.post(url, json=body, headers=self.getHeaders()).text
        print("创建生成任务成功：\n", response)
        resp = json.loads(response)
        if (0 == resp['code']):
            return resp['data']['sid']
        else:
            print('创建PPT任务失败')
            return None


if __name__ == '__main__':
    # 控制台获取
    APPId = "XXXXXXXX"
    APISecret = "XXXXXXXXXXXXXXXXXXXXXXXX"

    # 查询PPT主题列表
    # demo1 = AIPPT(APPId,APISecret,'','')
    # templateId = demo1.getTheme() # 获取模板列表
    # print("支持模板列表：\n",templateId)
    templateId = "20240718489569D"  # 该模板ID，需要通过getTheme() 方法获取模板列表，然后从中挑选

    # 流程一：根据描述或者文档直接生成PPT；(流程一、流程二代码不能同时打开)
    # # 流程一开始
    Text = "请帮我写一份PPT： 介绍下今年到目前位置的公司经营状况"
    demo = AIPPT(APPId, APISecret, Text, templateId)
    taskid = demo.create_task()
    # # 流程一结束

    # 流程二： 先生成大纲(支持上传文本)，再通过大纲生成PPT；(流程一、流程二代码不能同时打开)

    # # 流程二开始
    # title = "秋分时节的农业管理策略"   #设定大纲主题
    # filename = "test.pdf" # 需要根据文档上传时，请填写文档路径；要求：字数不得超过8000字，文件限制10M。上传文件支持pdf(不支持扫描件)、doc、docx、txt、md格式的文件。
    # filePath = "data/test.pdf" # 文件路径，也可以通过fileurl 字段上传对象存储地址，具体见方法：createOutlineByDoc
    # demo = AIPPT(APPId, APISecret, title, templateId)
    # res = demo.createOutlineByDoc(fileName=filename,filePath=filePath)
    # data = json.loads(res)
    # outline = data["data"]["outline"]
    # taskid = demo.createPptByOutline(outline)
    # # 流程二结束

    result = demo.get_result(taskid)
    print("生成的PPT请从此地址获取：\n" + result)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : database
# @Time         : 2024/11/20 10:25
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 基础操作 https://mp.weixin.qq.com/s/nbYhmkN05eqnvjGFvzMbXQ

from meutils.pipe import *

from sqlalchemy.ext.asyncio import create_async_engine
from sqlmodel.ext.asyncio.session import AsyncSession
from sqlmodel import Field, Session, SQLModel, create_engine, select, insert, update

engine = create_async_engine(
    os.getenv("MYSQL_URL"),
    future=True,
    pool_size=64,
    max_overflow=64,
    pool_recycle=3600,
    echo=True,
)


async def create_db_and_tables() -> None:
    meta = SQLModel.metadata

    async with engine.begin() as conn:
        # await conn.run_sync(meta.drop_all) # 清空 慎用
        await conn.run_sync(meta.create_all)


async def get_session():
    async with AsyncSession(engine) as session:
        yield session


async def get_db():
    async with AsyncSession(engine) as session:
        yield session


async def update_or_insert(entity, filter_kwargs: Optional[dict] = None, update_fn: Optional[Callable] = None,
                           n: int = 1):
    """

    :param entity: TASK 类
    :param filter_kwargs: 查询条件 字典 元组 第一个值是id
    :param update_fn:

        def update_fn(data):
            data.age = 100

    :param n: 轮询次数
    :return:
    """
    if n > 1:  # 一般轮询任务放后台
        for i in range(1, n):
            await asyncio.sleep(n / i, 1)

            logger.debug(f"UPDATE_OR_INSERT: {entity.__name__}-{i}")
            update_flag = await update_or_insert(entity, filter_kwargs, update_fn)
            if update_flag is False:
                logger.debug("提前跳出轮询")
                break

    filter_kwargs = filter_kwargs or {}
    async with AsyncSession(engine) as session:
        statement = select(entity).filter_by(**filter_kwargs)
        result = await session.exec(statement)
        data = result.first()  # result.all()

        if data:  # 主键id查询
            if update_fn:
                logger.debug(f"UPDATE: {data}")

                if inspect.iscoroutinefunction(update_fn):
                    update_flag = await update_fn(data)
                else:
                    update_flag = update_fn(data)

                if update_flag is False: return False  # 跳出轮询

                await session.commit()
                await session.refresh(data)
            return data
        else:
            data = entity(**filter_kwargs)
            logger.debug(f"INSERT: {data}")

            session.add(data)

            await session.commit()
            await session.refresh(data)
            return data


async def select_first(entity, filter_kwargs: Optional[dict] = None):
    async with AsyncSession(engine) as session:
        statement = select(entity).filter_by(**filter_kwargs)

        if result := await session.exec(statement):
            _ = result.first()
            logger.debug(_)
            return _


if __name__ == '__main__':
    pass

    # class Hero(SQLModel, table=True):
    #     id: Optional[int] = Field(default=None, primary_key=True)
    #     name: str
    #     secret_name: str
    #     age: Optional[int] = None
    #
    #
    # hero_1 = Hero(name="Deadpond", secret_name="Dive Wilson")
    # hero_2 = Hero(name="Spider-Boy", secret_name="Pedro Parqueador")
    # hero_3 = Hero(name="Rusty-Man", secret_name="Tommy Sharp", age=48)
    #
    #
    # async def main():
    #     async with AsyncSession(engine) as session:
    #         session.add(hero_1)
    #         session.add(hero_2)
    #         session.add(hero_3)
    #         await session.commit()
    #
    #
    # # arun(main())
    #
    # arun(create_db_and_tables())

    from meutils.schemas.db.oneapi_types import OneapiTask, OneapiUser, OneapiToken

    # filter_kwargs = {
    #     "task_id": "888",
    # }
    #
    #
    # async def main():
    #     async with AsyncSession(engine) as session:
    #         statement = select(OneapiTask).filter_by(**filter_kwargs)
    #         result = await session.exec(statement)
    #         logger.debug(result)
    #         if result:
    #             logger.debug(result.first())
    #         # await session.commit()
    #
    #
    # arun(update_or_insert(OneapiTask, filter_kwargs))

    filter_kwargs = {
        "id": "1",
    }


    async def main():
        async with AsyncSession(engine) as session:
            # filter_kwargs = {
            #     "id": "1",
            # }
            # statement = select(OneapiUser).filter_by(**filter_kwargs)

            filter_kwargs = {
                "key": "gpoH1z3G6nHovD8MY40i6xx5tsC1vbh7B3Aao2jmejYNoKhv",
            }
            statement = select(OneapiToken).filter_by(**filter_kwargs)

            result = await session.exec(statement)
            if result:
                logger.debug(result.first())
            # await session.commit()


    arun(main())



# -*- coding: utf-8 -*-

from __future__ import absolute_import

from .base import Type


class Woff(Type):
    """
    Implements the WOFF font type matcher.
    """
    MIME = 'application/font-woff'
    EXTENSION = 'woff'

    def __init__(self):
        super(Woff, self).__init__(
            mime=Woff.MIME,
            extension=Woff.EXTENSION
        )

    def match(self, buf):
        return (len(buf) > 7 and
                buf[0] == 0x77 and
                buf[1] == 0x4F and
                buf[2] == 0x46 and
                buf[3] == 0x46 and
                ((buf[4] == 0x00 and
                  buf[5] == 0x01 and
                  buf[6] == 0x00 and
                  buf[7] == 0x00) or
                 (buf[4] == 0x4F and
                  buf[5] == 0x54 and
                  buf[6] == 0x54 and
                  buf[7] == 0x4F) or
                 (buf[4] == 0x74 and
                  buf[5] == 0x72 and
                  buf[6] == 0x75 and
                  buf[7] == 0x65)))


class Woff2(Type):
    """
    Implements the WOFF2 font type matcher.
    """
    MIME = 'application/font-woff'
    EXTENSION = 'woff2'

    def __init__(self):
        super(Woff2, self).__init__(
            mime=Woff2.MIME,
            extension=Woff2.EXTENSION
        )

    def match(self, buf):
        return (len(buf) > 7 and
                buf[0] == 0x77 and
                buf[1] == 0x4F and
                buf[2] == 0x46 and
                buf[3] == 0x32 and
                ((buf[4] == 0x00 and
                  buf[5] == 0x01 and
                  buf[6] == 0x00 and
                  buf[7] == 0x00) or
                 (buf[4] == 0x4F and
                  buf[5] == 0x54 and
                  buf[6] == 0x54 and
                  buf[7] == 0x4F) or
                 (buf[4] == 0x74 and
                  buf[5] == 0x72 and
                  buf[6] == 0x75 and
                  buf[7] == 0x65)))


class Ttf(Type):
    """
    Implements the TTF font type matcher.
    """
    MIME = 'application/font-sfnt'
    EXTENSION = 'ttf'

    def __init__(self):
        super(Ttf, self).__init__(
            mime=Ttf.MIME,
            extension=Ttf.EXTENSION
        )

    def match(self, buf):
        return (len(buf) > 4 and
                buf[0] == 0x00 and
                buf[1] == 0x01 and
                buf[2] == 0x00 and
                buf[3] == 0x00 and
                buf[4] == 0x00)


class Otf(Type):
    """
    Implements the OTF font type matcher.
    """
    MIME = 'application/font-sfnt'
    EXTENSION = 'otf'

    def __init__(self):
        super(Otf, self).__init__(
            mime=Otf.MIME,
            extension=Otf.EXTENSION
        )

    def match(self, buf):
        return (len(buf) > 4 and
                buf[0] == 0x4F and
                buf[1] == 0x54 and
                buf[2] == 0x54 and
                buf[3] == 0x4F and
                buf[4] == 0x00)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : gradio
# @Time         : 2024/9/27 10:25
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 


from meutils.pipe import *
from meutils.apis.proxy import ips

from gradio_client import Client, handle_file as _handle_file

handle_file = lru_cache()(_handle_file)
@alru_cache()
async def create_client(endpoint, hf_token: Optional[str]=None, with_proxies: bool = False):
    httpx_kwargs = None
    if with_proxies:  # 无法使用
        proxies = await ips.get_proxies()
        httpx_kwargs = {
            "proxies": proxies,
        }

    client = Client(
        endpoint,
        download_files=False,
        httpx_kwargs=httpx_kwargs,
        hf_token=hf_token
    )

    return client



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : images
# @Time         : 2025/4/18 08:55
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
"""
https://www.volcengine.com/docs/85128/1526761
Seedream 通用3.0文生图模型是基于字节跳动视觉大模型打造的新一代文生图模型，本次升级模型综合能力（图文，结构，美感）均显著提升。V3.0参数量更大，对语义有更好的理解，实体结构也更加自然真实，支持 2048 以下分辨率直出，各类场景下的效果均大幅提升。
https://www.volcengine.com/docs/6791/1384311
"""

from meutils.pipe import *
from meutils.decorators.retry import retrying

from meutils.io.files_utils import to_url
from meutils.schemas.image_types import ImageRequest, ImagesResponse

from volcengine.visual.VisualService import VisualService


@retrying()
async def generate(request: ImageRequest, token: Optional[str] = None):
    """

    :param request: byteedit_v2.0 high_aes_general_v30l_zt2i Seedream
    :param token:
    :return:
    """
    visual_service = VisualService()

    if token:
        ak, sk = token.split('|')
        visual_service.set_ak(ak)
        visual_service.set_sk(sk)

    # request byteedit_v2.0 high_aes_general_v30l_zt2i
    payload = {
        "req_key": "high_aes_general_v30l_zt2i",
        # "req_key": "jimeng_high_aes_general_v21_L",

        "prompt": request.prompt,
        "seed": request.seed,
        "width": 1328,
        "height": 1328,
        "return_url": request.response_format == "url",  # 24小时

        # # prompt进行扩写优化
        # "use_pre_llm": True,
        # "use_rephraser": True
    }

    image, prompt = request.image_and_prompt
    width, height = map(int, request.size.split('x'))

    if image:
        payload["image_urls"] = [image]
        payload["req_key"] = request.model
        if payload["req_key"] not in {"seededit_v3.0", "byteedit_v2.0"}:
            payload["req_key"] = "byteedit_v2.0"  # "seededit_v3.0" https://www.volcengine.com/docs/85128/1602254

    payload['width'] = width
    payload['height'] = height

    if request.response_format == "oss_url":
        payload["return_url"] = False

    response = visual_service.cv_process(payload)
    logger.debug(bjson(response))

    if request.response_format == "b64_json":
        data = [{"b64_json": b64_json} for b64_json in response['data'].get('binary_data_base64', [])]

    elif request.response_format == "oss_url":
        urls = await to_url(response['data'].get('binary_data_base64', []), filename='.png')
        data = [{"url": url} for url in urls]
    else:
        data = [{"url": url.replace(r'\u0026', '&')} for url in response['data'].get('image_urls', [])]

    response['data'].pop("binary_data_base64", None)
    response = ImagesResponse(
        data=data,
        metadata=response
    )

    return response


if __name__ == '__main__':
    token = f"""{os.getenv("VOLC_ACCESSKEY")}|{os.getenv("VOLC_SECRETKEY")}"""
    token = "AKLTOWM5ZTc5ZDFhZWNlNDIzODkwYmZiNjEyNzYwNzE0MTI|T0RCbFpHRTJaRFEyWmpjeE5ERXpNR0ptWlRCaU16WmhPRE0wWVdKa01tTQ=="
    prompt = """
    3D魔童哪吒 c4d 搬砖 很开心， 很快乐， 精神抖擞， 背景是数不清的敖丙虚化 视觉冲击力强 大师构图 色彩鲜艳丰富 吸引人 背景用黄金色艺术字写着“搬砖挣钱” 冷暖色对比
    """

    # prompt = """
    # https://oss.ffire.cc/files/kling_watermark.png
    # 让这个女人带上眼镜 衣服换个颜色
    # """

    request = ImageRequest(
        model="high_aes_general_v30l_zt2i",
        prompt=prompt,
        response_format="url",
        size="512x1328",
    )

    arun(generate(request, token=token))

    # with timer():
    #     visual_service = VisualService()
    #     visual_service.set_ak('your ak')  # AKLTZmU5OTA1NTk2MTNmNGQ0MTgxZjQ1NzI0Y2MzYjlhMDQ
    #     visual_service.set_sk('your sk')

    # call below method if you don't set ak and sk in $HOME/.volc/config
    # visual_service.set_ak('your ak') # AKLTZmU5OTA1NTk2MTNmNGQ0MTgxZjQ1NzI0Y2MzYjlhMDQ
    # visual_service.set_sk('your sk')

    # 请求Body(查看接口文档请求参数-请求示例，将请求参数内容复制到此)
    # form = {
    #     "req_key": "xxx",
    #     # ...
#     # }
#     "high_aes_scheduler_svr_controlnet_v2.0"
#     prompt = """
# 3D魔童哪吒 c4d 搬砖 很开心， 很快乐， 精神抖擞， 背景是数不清的敖丙虚化 视觉冲击力强 大师构图 色彩鲜艳丰富 吸引人 背景用黄金色艺术字写着“搬砖挣钱” 冷暖色对比
#     """
#     form = {
#         "req_key": "high_aes_general_v30l_zt2i",
#
#         "req_key": "byteedit_v2.0",
#         "prompt": "让这个女人笑起来",
#         "image_urls": ["https://oss.ffire.cc/files/kling_watermark.png"],  # binary_data_base64
#
#         "scale": 0.5,  # [1, 10]
#
#         # "prompt": prompt,
#         # "use_pre_llm": True,  # prompt进行扩写优化
#         # "use_rephraser": True,  # prompt进行扩写优化
#         "seed": -1,
#         # "scale": 2.5,  # [1, 10]
#         "width": 1328,  # [512, 2048]
#         "height": 1328,
#         "return_url": True,  # 24小时
#         # "logo_info": {
#         #     "add_logo": False,
#         #     "position": 0,
#         #     "language": 0,
#         #     "opacity": 0.3,
#         #     "logo_text_content": "这里是明水印内容"
#         # }
#     }
#     with timer():
#         resp = visual_service.cv_process(form)
#         print(resp)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : haimian_types
# @Time         : 2024/8/2 15:25
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : model=灵感创作 model=自定义创作

from meutils.pipe import *


# https://www.haimian.com/jd/api/v1/generate/text2bgm 纯音乐


class HaimianRequest(BaseModel):
    prompt: str
    batch_size: int = 1

    generate_cover: bool = True
    generate_title: bool = True
    is_original_prompt: bool = False


class HaimianCustomRequest(HaimianRequest):
    # 自定义模式
    title: Optional[str] = None
    lyrics: str

    genre: Optional[Union[str, Literal[
        "Folk", "Pop", "Rock", "Romantic", "GuFeng Music", "Hip Hop/Rap", "R&B/Soul", "Jazz", "Reggae",
        "Chinoiserie Electronic", "Trap Rap""Contemporary R&B", "Bossa Nova",
    ]]] = None

    mood: Optional[Union[str, Literal[
        "Happy",
        "Sentimental/Melancholic/Lonely",  # emo
        "Dynamic/Energetic",  # 活力
        "Nostalgic/Memory",  # 怀旧
        "Groovy/Funky",  # 律动
        "Sorrow/Sad",  # 伤感
        "Chill",  # 放松
        "Romantic",  # 浪漫
    ]]] = None

    gender: Optional[Literal["Male", "Female"]] = None

    is_original_tag: bool = False

    source_lyric_id: Optional[str] = None



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : cf_asr
# @Time         : 2024/5/7 16:43
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
import httpx

from meutils.pipe import *
from meutils.str_utils import chinese_convert

# curl https://api.cloudflare.com/client/v4/accounts/$CLOUDFLARE_ACCOUNT_ID/ai/run/@cf/openai/whisper \
#   -X POST \
#   -H "Authorization: Bearer $CLOUDFLARE_API_TOKEN" \
#   --data-binary "@talking-llama.mp3"
from fastapi import APIRouter, File, UploadFile, Query, Form, Depends, Request, HTTPException, status


cloudflare_account_id, api_key = os.getenv("CLOUDFLARE_API_TOKEN").split('-', maxsplit=1)

base_url = f"https://api.cloudflare.com/client/v4/accounts/{cloudflare_account_id}/ai/run"

headers = {"Authorization": f"Bearer {api_key}"}

httpx_client = httpx.Client(base_url=base_url, follow_redirects=True, timeout=100, headers=headers)
httpx_aclient = httpx.AsyncClient(base_url=base_url, follow_redirects=True, timeout=100, headers=headers)

file = open("f275d9ac-5a62-4bbe-baf9-3fa10e0332f4.mp3", 'rb')
payload = {"file": (file.name, file)}
#
# file = UploadFile(file)
# payload = {"file": (file.filename, file.file)}
#
# file = httpx.get("https://oss.chatfire.cn/data/demo.mp3").content
# payload = {"file": ('demo', file)}




# with timer('asr'):
#     response = httpx_client.post("@cf/openai/whisper", files=payload)
#     print(chinese_convert(bjson(response.json())))

if __name__ == '__main__':
    async def asr():
        response: httpx.Response = await httpx_aclient.post("@cf/openai/whisper", files=payload)
        return response.json()


    print(arun(asr()))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : tasks
# @Time         : 2025/6/18 16:51
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 


from meutils.pipe import *
from meutils.llm.clients import AsyncOpenAI


# dynamic_router
# async def create_task(
#         request: dict,
#         api_key: Optional[str] = None
# ):
#     payload = request
#     client = AsyncOpenAI(base_url=base_url, api_key=api_key)
#     response = client.post(
#         ,
#         body=payload,
#         cast_to=dict,
#     )
#     return response



#!/usr/bin/env Python
# -*- coding: utf-8 -*-

from meutils.pipe import *
from meutils.caches import rcache
from meutils.decorators.retry import retrying

username = "d1982743732"
password = "1h29rymg"


@rcache(ttl=2.5 * 60)
@retrying()
async def get_proxy_list(n: int = 1):
    secret_id = os.getenv("KDLAPI_SECRET_ID")
    signature = os.getenv("KDLAPI_SIGNATURE")
    url = f"https://dps.kdlapi.com/api/getdps/?secret_id={secret_id}&signature={signature}&num={n}&pt=1&format=json&sep=1"
    async with httpx.AsyncClient(timeout=30) as client:
        response = await client.get(url)
        response.raise_for_status()
        proxy_list = response.json().get('data').get('proxy_list')

        logger.debug(f"获取到的代理: {proxy_list}")

        return [f"http://{username}:{password}@{proxy}" for proxy in proxy_list]


async def get_one_proxy():
    proxy_list = await get_proxy_list()
    return proxy_list[-1]


if __name__ == '__main__':
    # arun(get_proxy_list())

    page_url = "https://icanhazip.com/"  # 要访问的目标网页


    # page_url = "https://httpbin.org/ip"

    async def fetch(url):
        proxy = await get_one_proxy()
        # proxy = "http://154.9.253.9:38443"
        # # proxy="https://tinyproxy.chatfire.cn"
        # # proxy="https://pp.chatfire.cn"
        # proxy = "http://110.42.51.201:38443"
        # proxy = "http://110.42.51.223:38443"
        # proxy = "http://110.42.51.223:38443"

        # proxy=None
        # proxy = "https://npjdodcrxljt.ap-northeast-1.clawcloudrun.com"

        async with httpx.AsyncClient(proxy=proxy, timeout=30) as client:
            resp = await client.get(url)
            logger.debug((f"status_code: {resp.status_code}, content: {resp.text}"))


    def run():
        loop = asyncio.get_event_loop()
        # 异步发出5次请求
        tasks = [fetch(page_url) for _ in range(3)]
        loop.run_until_complete(asyncio.wait(tasks))


    # run()

    arun(get_one_proxy())
